@@ -7,7 +7,6 @@ module Data.ListLike.Text.TextLazy
 where
 
 import           Prelude as P
-import           Control.Monad
 import qualified Data.Text.Lazy as T
 import qualified Data.Text.Lazy.IO as TI
 import           Data.Text.Encoding (decodeUtf8)
@@ -75,8 +74,8 @@ instance ListLike T.Text Char where
     genericSplitAt i = T.splitAt (fromIntegral i)
     genericReplicate i = LL.replicate (fromIntegral i)
 
-    sequence  = liftM fromList . P.sequence  . toList
-    mapM func = liftM fromList . P.mapM func . toList
+    sequence  = fmap fromList . P.sequenceA  . toList
+    mapM func = fmap fromList . P.traverse func . toList
 
 instance ListLikeIO T.Text Char where
     hGetLine = TI.hGetLine
