@@ -15,8 +15,8 @@ For license and copyright information, see the file COPYRIGHT
    Copyright  : Copyright (C) 2007 John Goerzen
    License    : BSD3
 
-   Maintainer : John Lato <jwlato@gmail.com>
-   Stability  : provisional
+   Maintainer : David Fox <dsf@seereason.com>, Andreas Abel
+   Stability  : stable
    Portability: portable
 
 Utilities for 'Data.ListLike.ListLike' and friends.  More functions
@@ -40,7 +40,6 @@ import Prelude hiding (length, head, last, null, tail, map, filter, concat,
 import Control.Monad (MonadPlus(..))
 import Data.ListLike.Base
 import Data.ListLike.FoldableLL
-import Data.Maybe (maybe)
 import Data.Monoid
 
 -- | Returns True if all elements are True
